@@ -39,21 +39,21 @@
 #include <tqtoolbutton.h>
 #include <tqwhatsthis.h>
 
-#include <kaccel.h>
-#include <kapplication.h>
+#include <tdeaccel.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <kedittoolbar.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kkeydialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 #include <ktabwidget.h> 
 #include <kurldrag.h>
-#include <kwin.h>
+#include <twin.h>
 
 KTechlab::KTechlab()
 	: KateMDI::MainWindow( 0, "KTechlab" )
@@ -80,7 +80,7 @@ KTechlab::KTechlab()
 	setupToolDocks();
 	setupActions();
 	setupView();
-	readProperties( KGlobal::config() );
+	readProperties( TDEGlobal::config() );
 	
 // 	kdDebug() << "Constructor time: " << ct.elapsed() << endl;
 }
@@ -121,11 +121,11 @@ void KTechlab::load( const KURL & url )
 	// want to use this code instead for your app
 	
 	// download the contents
-	if ( !KIO::NetAccess::download( url, target, this ) )
+	if ( !TDEIO::NetAccess::download( url, target, this ) )
 	{
 		// If the file could not be downloaded, for example does not
 		// exist on disk, NetAccess will tell us what error to use
-		KMessageBox::error(this, KIO::NetAccess::lastErrorString());
+		KMessageBox::error(this, TDEIO::NetAccess::lastErrorString());
 		
 		return;
 	}
@@ -139,7 +139,7 @@ void KTechlab::load( const KURL & url )
 	DocManager::self()->openURL( target );
 	
 	// and remove the temp file
-	KIO::NetAccess::removeTempFile( target );
+	TDEIO::NetAccess::removeTempFile( target );
 }
 
 
@@ -151,19 +151,19 @@ TQStringList KTechlab::recentFiles()
 
 void KTechlab::setupToolDocks()
 {
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
+#if defined(TDE_MAKE_VERSION)
+# if TDE_VERSION >= TDE_MAKE_VERSION(3,3,0)
 	setToolViewStyle( KMultiTabBar::KDEV3ICON );
 # endif
 #endif
 	
 	TQPixmap pm;
-	KIconLoader * loader = KGlobal::iconLoader();
+	TDEIconLoader * loader = TDEGlobal::iconLoader();
 	KateMDI::ToolView * tv = 0l;
 	
 	tv = createToolView( ProjectManager::toolViewIdentifier(),
 						 KMultiTabBar::Left,
-						 loader->loadIcon( "attach", KIcon::Small ),
+						 loader->loadIcon( "attach", TDEIcon::Small ),
 						 i18n("Project") );
 	ProjectManager::self( this, tv );
 	
@@ -203,20 +203,20 @@ void KTechlab::setupToolDocks()
 	
 	tv = createToolView( ContextHelp::toolViewIdentifier(),
 						 KMultiTabBar::Right,
-						 loader->loadIcon( "contents", KIcon::Small ),
+						 loader->loadIcon( "contents", TDEIcon::Small ),
 						 i18n("Context Help") );
 	ContextHelp::self(tv);
 	
 	tv = createToolView( LanguageManager::toolViewIdentifier(),
 						 KMultiTabBar::Bottom,
-						 loader->loadIcon( "log", KIcon::Small ),
+						 loader->loadIcon( "text-x-log", TDEIcon::Small ),
 						 i18n("Messages") );
 	LanguageManager::self( tv, this );
 	
 #ifndef NO_GPSIM
 	tv = createToolView( SymbolViewer::toolViewIdentifier(),
 						 KMultiTabBar::Right,
-						 loader->loadIcon( "blockdevice", KIcon::Small ),
+						 loader->loadIcon( "blockdevice", TDEIcon::Small ),
 						 i18n("Symbol Viewer") );
 	SymbolViewer::self(tv);
 #endif
@@ -275,13 +275,13 @@ void KTechlab::overlayToolBarScreenshot()
 		return;
 	}
 	
-	TQPtrListIterator<KToolBar> toolBarIterator();
+	TQPtrListIterator<TDEToolBar> toolBarIterator();
 	
 // 	TQWidget * toolsWidget = toolBar( "toolsToolBar" );
 // 	TQWidget * debugWidget = toolBar( "debugTB" );
 	
-	KToolBar * toolsWidget = static_cast<KToolBar*>(TQT_TQWIDGET(child( "toolsToolBar", "KToolBar" )));
-	KToolBar * debugWidget = static_cast<KToolBar*>(TQT_TQWIDGET(child( "debugTB", "KToolBar" )));
+	TDEToolBar * toolsWidget = static_cast<TDEToolBar*>(TQT_TQWIDGET(child( "toolsToolBar", "TDEToolBar" )));
+	TDEToolBar * debugWidget = static_cast<TDEToolBar*>(TQT_TQWIDGET(child( "debugTB", "TDEToolBar" )));
 	
 	if ( !toolsWidget && !debugWidget )
 		return;
@@ -366,7 +366,7 @@ void KTechlab::setupTabWidget()
 	connect( tabWidget(), TQT_SIGNAL(receivedDropEvent(TQDropEvent* )), TQT_TQOBJECT(this), TQT_SLOT(slotTabReceivedDropEvent(TQDropEvent* )) );
 	connect( tabWidget(), TQT_SIGNAL(receivedDropEvent(TQWidget*, TQDropEvent* )), TQT_TQOBJECT(this), TQT_SLOT(slotTabReceivedDropEvent(TQWidget*, TQDropEvent* )) );
 	
-	KConfig *config = kapp->config();
+	TDEConfig *config = kapp->config();
 	config->setGroup("UI");
 		
 	bool CloseOnHover = config->readBoolEntry( "CloseOnHover", false );
@@ -410,7 +410,7 @@ void KTechlab::slotUpdateTabWidget()
 
 void KTechlab::setupActions()
 {
-	KActionCollection *ac = actionCollection();
+	TDEActionCollection *ac = actionCollection();
 	
     KStdAction::openNew(			TQT_TQOBJECT(this), TQT_SLOT(slotFileNew()),					ac );
     KStdAction::open(				TQT_TQOBJECT(this), TQT_SLOT(slotFileOpen()),					ac );
@@ -429,16 +429,16 @@ void KTechlab::setupActions()
 	KStdAction::preferences(		TQT_TQOBJECT(this), TQT_SLOT(slotOptionsPreferences()),		ac );
 	
 	//BEGIN New file popup
-	KToolBarPopupAction *p = new KToolBarPopupAction( i18n("&New"), "filenew", KStdAccel::shortcut(KStdAccel::New), TQT_TQOBJECT(this), TQT_SLOT(slotFileNew()), ac, "newfile_popup" );
+	TDEToolBarPopupAction *p = new TDEToolBarPopupAction( i18n("&New"), "document-new", TDEStdAccel::shortcut(TDEStdAccel::New), TQT_TQOBJECT(this), TQT_SLOT(slotFileNew()), ac, "newfile_popup" );
 	p->popupMenu()->insertTitle( i18n("New File") );
-	(new KAction( i18n("Assembly"), "source", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewAssembly()), ac, "newfile_asm" ))->plug( p->popupMenu() );
-	(new KAction( i18n("C source"), "source_c", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewC()), ac, "newfile_c" ))->plug( p->popupMenu() );
-	(new KAction( i18n("Circuit"), "ktechlab_circuit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewCircuit()), ac, "newfile_circuit" ))->plug( p->popupMenu() );
-	(new KAction( i18n("FlowCode"), "ktechlab_flowcode", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewFlowCode()), ac, "newfile_flowcode" ))->plug( p->popupMenu() );
+	(new TDEAction( i18n("Assembly"), "text-x-src", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewAssembly()), ac, "newfile_asm" ))->plug( p->popupMenu() );
+	(new TDEAction( i18n("C source"), "text-x-csrc", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewC()), ac, "newfile_c" ))->plug( p->popupMenu() );
+	(new TDEAction( i18n("Circuit"), "ktechlab_circuit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewCircuit()), ac, "newfile_circuit" ))->plug( p->popupMenu() );
+	(new TDEAction( i18n("FlowCode"), "ktechlab_flowcode", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewFlowCode()), ac, "newfile_flowcode" ))->plug( p->popupMenu() );
 #ifdef MECHANICS
-	(new KAction( i18n("Mechanics"), "ktechlab_mechanics", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewMechanics()), ac, "newfile_mechanics" ))->plug( p->popupMenu() );
+	(new TDEAction( i18n("Mechanics"), "ktechlab_mechanics", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewMechanics()), ac, "newfile_mechanics" ))->plug( p->popupMenu() );
 #endif
-	(new KAction( "Microbe", "ktechlab_microbe", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewMicrobe()), ac, "newfile_microbe" ))->plug( p->popupMenu() );
+	(new TDEAction( "Microbe", "ktechlab_microbe", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFileNewMicrobe()), ac, "newfile_microbe" ))->plug( p->popupMenu() );
 	//END New File popup
 	
 
@@ -448,34 +448,34 @@ void KTechlab::setupActions()
 	
 	//BEGIN Project Actions
 	ProjectManager *pm = ProjectManager::self(this);
-	new KAction( i18n("New Project.."), "window_new",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotNewProject()),			ac, 	"project_new" );
-	new KAction( i18n("Open Project..."), "project_open",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotOpenProject()),			ac, 	"project_open" );
-// 	m_recentProjects = new KRecentFilesAction( i18n("Open &Recent Project..."), 0, ProjectManager::self(), TQT_SLOT(slotOpenProject(const KURL&)), ac, "project_open_recent" );
+	new TDEAction( i18n("New Project.."), "window-new",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotNewProject()),			ac, 	"project_new" );
+	new TDEAction( i18n("Open Project..."), "project_open",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotOpenProject()),			ac, 	"project_open" );
+// 	m_recentProjects = new TDERecentFilesAction( i18n("Open &Recent Project..."), 0, ProjectManager::self(), TQT_SLOT(slotOpenProject(const KURL&)), ac, "project_open_recent" );
 	m_recentProjects = new RecentFilesAction( "Recent Projects", i18n("Open &Recent Project..."), TQT_TQOBJECT(ProjectManager::self()), TQT_SLOT(slotOpenProject(const KURL&)), ac, "project_open_recent" );
-	new KAction( i18n("Export to Makefile..."), "fileexport",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotExportToMakefile()),		ac, "project_export_makefile" );
-	new KAction( i18n("Create Subproject..."), 0,				0, TQT_TQOBJECT(pm), TQT_SLOT(slotCreateSubproject()),		ac, "project_create_subproject" );
-	new KAction( i18n("Add Existing File..."), "fileopen",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotAddFile()),					ac, "project_add_existing_file" );
-	new KAction( i18n("Add Current File..."), "fileimport",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotAddCurrentFile()),			ac, "project_add_current_file" );
-// 	new KAction( i18n("Project Options"), "configure",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotProjectOptions()),			ac, "project_options" );
-	new KAction( i18n("Close Project"), "fileclose",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotCloseProject()),			ac, "project_close" );
-	new KAction( i18n("Remove from Project"), "editdelete",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotRemoveSelected()),			ac, "project_remove_selected" );
-	new KAction( i18n("Insert Existing File..."), "fileopen",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotSubprojectAddExistingFile()),	ac, "subproject_add_existing_file" );
-	new KAction( i18n("Insert Current File..."), "fileimport",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotSubprojectAddCurrentFile()),ac, "subproject_add_current_file" );
-	new KAction( i18n("Linker Options..."), "configure",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotSubprojectLinkerOptions()),	ac, "project_item_linker_options" );
-	new KAction( i18n("Build..."), "launch",					0, TQT_TQOBJECT(pm), TQT_SLOT(slotItemBuild()),				ac, "project_item_build" );
-	new KAction( i18n("Upload..."), "convert_to_pic",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotItemUpload()),				ac, "project_item_upload" );
-	new KAction( i18n("Processing Options..."), "configure",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotItemProcessingOptions()),	ac, "project_item_processing_options" );
+	new TDEAction( i18n("Export to Makefile..."), "fileexport",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotExportToMakefile()),		ac, "project_export_makefile" );
+	new TDEAction( i18n("Create Subproject..."), 0,				0, TQT_TQOBJECT(pm), TQT_SLOT(slotCreateSubproject()),		ac, "project_create_subproject" );
+	new TDEAction( i18n("Add Existing File..."), "document-open",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotAddFile()),					ac, "project_add_existing_file" );
+	new TDEAction( i18n("Add Current File..."), "fileimport",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotAddCurrentFile()),			ac, "project_add_current_file" );
+// 	new TDEAction( i18n("Project Options"), "configure",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotProjectOptions()),			ac, "project_options" );
+	new TDEAction( i18n("Close Project"), "window-close",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotCloseProject()),			ac, "project_close" );
+	new TDEAction( i18n("Remove from Project"), "edit-delete",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotRemoveSelected()),			ac, "project_remove_selected" );
+	new TDEAction( i18n("Insert Existing File..."), "document-open",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotSubprojectAddExistingFile()),	ac, "subproject_add_existing_file" );
+	new TDEAction( i18n("Insert Current File..."), "fileimport",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotSubprojectAddCurrentFile()),ac, "subproject_add_current_file" );
+	new TDEAction( i18n("Linker Options..."), "configure",		0, TQT_TQOBJECT(pm), TQT_SLOT(slotSubprojectLinkerOptions()),	ac, "project_item_linker_options" );
+	new TDEAction( i18n("Build..."), "launch",					0, TQT_TQOBJECT(pm), TQT_SLOT(slotItemBuild()),				ac, "project_item_build" );
+	new TDEAction( i18n("Upload..."), "convert_to_pic",			0, TQT_TQOBJECT(pm), TQT_SLOT(slotItemUpload()),				ac, "project_item_upload" );
+	new TDEAction( i18n("Processing Options..."), "configure",	0, TQT_TQOBJECT(pm), TQT_SLOT(slotItemProcessingOptions()),	ac, "project_item_processing_options" );
 	//END Project Actions
 	
-	new KAction( i18n("Split View Left/Right"), "view_right", TQt::CTRL|TQt::SHIFT|TQt::Key_L, TQT_TQOBJECT(this), TQT_SLOT(slotViewSplitLeftRight()), ac, "view_split_leftright" );
-	new KAction( i18n("Split View Top/Bottom"), "view_bottom", TQt::CTRL|TQt::SHIFT|TQt::Key_T, TQT_TQOBJECT(this), TQT_SLOT(slotViewSplitTopBottom()), ac, "view_split_topbottom" );
+	new TDEAction( i18n("Split View Left/Right"), "view_right", TQt::CTRL|TQt::SHIFT|TQt::Key_L, TQT_TQOBJECT(this), TQT_SLOT(slotViewSplitLeftRight()), ac, "view_split_leftright" );
+	new TDEAction( i18n("Split View Top/Bottom"), "view_bottom", TQt::CTRL|TQt::SHIFT|TQt::Key_T, TQT_TQOBJECT(this), TQT_SLOT(slotViewSplitTopBottom()), ac, "view_split_topbottom" );
 	
-	KToggleAction * ta = new KToggleAction( i18n("Run Simulation"), "player_play", TQt::Key_F10, 0, 0, ac, "simulation_run" );
+	TDEToggleAction * ta = new TDEToggleAction( i18n("Run Simulation"), "media-playback-start", TQt::Key_F10, 0, 0, ac, "simulation_run" );
 	ta->setChecked(true);
 	connect( ta, TQT_SIGNAL(toggled(bool )), Simulator::self(), TQT_SLOT(slotSetSimulating(bool )) );
-#if defined(KDE_MAKE_VERSION)
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
-		ta->setCheckedState( KGuiItem( i18n("Pause Simulation"), "player_pause", 0 ) );
+#if defined(TDE_MAKE_VERSION)
+# if TDE_VERSION >= TDE_MAKE_VERSION(3,3,0)
+		ta->setCheckedState( KGuiItem( i18n("Pause Simulation"), "media-playback-pause", 0 ) );
 # endif
 #endif
 	
@@ -554,11 +554,11 @@ void KTechlab::slotTabReceivedDropEvent( TQWidget *widget, TQDropEvent *e )
 	}
 	e->accept(true);
 	
-	KPopupMenu dropMenu;
-	dropMenu.insertItem( KGlobal::iconLoader()->loadIcon( "goto", KIcon::Small ), i18n("&Insert Into"), 0 );
-	dropMenu.insertItem( KGlobal::iconLoader()->loadIcon( "editcopy", KIcon::Small ), i18n("&Copy Into"), 1 );
+	TDEPopupMenu dropMenu;
+	dropMenu.insertItem( TDEGlobal::iconLoader()->loadIcon( "goto", TDEIcon::Small ), i18n("&Insert Into"), 0 );
+	dropMenu.insertItem( TDEGlobal::iconLoader()->loadIcon( "edit-copy", TDEIcon::Small ), i18n("&Copy Into"), 1 );
 	dropMenu.insertSeparator();
-	dropMenu.insertItem( KGlobal::iconLoader()->loadIcon( "stop", KIcon::Small ), i18n("C&ancel"), 2 );
+	dropMenu.insertItem( TDEGlobal::iconLoader()->loadIcon( "process-stop", TDEIcon::Small ), i18n("C&ancel"), 2 );
 	
 	connect( &dropMenu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotDragContextActivated(int)) );
 // 	dropMenu.exec(e->pos() + widget->pos() );
@@ -587,18 +587,18 @@ void KTechlab::slotDragContextActivated( int id )
 }
 
 
-KAction * KTechlab::action( const TQString & name ) const
+TDEAction * KTechlab::action( const TQString & name ) const
 {
-	KAction * action = actionCollection()->action(name);
+	TDEAction * action = actionCollection()->action(name);
 	if ( !action )
 		kdError() << k_funcinfo << "No such action: " << name << endl;
 	return action;
 }
 
 
-void KTechlab::saveProperties( KConfig *conf )
+void KTechlab::saveProperties( TDEConfig *conf )
 {
-	// Dumbass KMainWindow - can't handle my width/height correctly. Whoever thought of the "+1" hack anyway?!
+	// Dumbass TDEMainWindow - can't handle my width/height correctly. Whoever thought of the "+1" hack anyway?!
 	conf->setGroup("UI");
 	conf->writeEntry( "Width", width() );
 	conf->writeEntry( "Height", height() );
@@ -634,7 +634,7 @@ void KTechlab::saveProperties( KConfig *conf )
 			continue;
 		
 		// To make sure the ViewContainers are restored in the right order, we must create them in alphabetical order,
-		// as KConfig stores them as such...
+		// as TDEConfig stores them as such...
 		const TQString id = TQString::number(viewContainerId++).rightJustify( 4, '0' );
 			
 		conf->setGroup( "ViewContainer " + id );
@@ -643,7 +643,7 @@ void KTechlab::saveProperties( KConfig *conf )
 	//END Open Views State
 	
 	saveSession( conf, "KateMDI" );
-	// Piss off KMainWindow
+	// Piss off TDEMainWindow
 	conf->setGroup("KateMDI");
 	int scnum = TQApplication::desktop()->screenNumber(parentWidget());
 	TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
@@ -654,7 +654,7 @@ void KTechlab::saveProperties( KConfig *conf )
 }
 
 
-void KTechlab::readProperties( KConfig *conf )
+void KTechlab::readProperties( TDEConfig *conf )
 {
 	startRestore( conf, "KateMDI" );
 	
@@ -695,7 +695,7 @@ void KTechlab::readProperties( KConfig *conf )
 	
 	finishRestore();
 	
-	// Dumbass KMainWindow - can't handle my width/height correctly. Whoever thought of the "+1" hack anyway?!
+	// Dumbass TDEMainWindow - can't handle my width/height correctly. Whoever thought of the "+1" hack anyway?!
 	conf->setGroup("UI");
 	resize( conf->readNumEntry( "Width", 800 ), conf->readNumEntry( "Height", 500 ) );
 	KWin::setState( winId(), conf->readLongNumEntry( "WinState", NET::Max ) );
@@ -765,10 +765,10 @@ void KTechlab::slotOptionsPreferences()
 	// An instance of your dialog could be already created and could be cached,
 	// in which case you want to display the cached dialog instead of creating
 	// another one
-	if ( KConfigDialog::showDialog( "settings" ) )
+	if ( TDEConfigDialog::showDialog( "settings" ) )
 		return;
 	
-	// KConfigDialog didn't find an instance of this dialog, so lets create it:
+	// TDEConfigDialog didn't find an instance of this dialog, so lets create it:
 	SettingsDlg* dialog = new SettingsDlg( this, "settings", KTLConfig::self() );
 	
 	// User edited the configuration - update your local copies of the
@@ -799,7 +799,7 @@ void KTechlab::slotTabContext( TQWidget* widget,const TQPoint & pos )
 {
 	// Shamelessly stolen from KDevelop...
 	
-	KPopupMenu * tabMenu = new KPopupMenu;
+	TDEPopupMenu * tabMenu = new TDEPopupMenu;
 	tabMenu->insertTitle( (dynamic_cast<ViewContainer*>(widget))->caption() );
 
 	//Find the document on whose tab the user clicked
@@ -1007,7 +1007,7 @@ KURL::List KTechlab::getFileURLs()
 void KTechlab::slotDocModifiedChanged()
 {
 	//BEGIN Set tab icons
-	KIconLoader *loader = KGlobal::iconLoader();
+	TDEIconLoader *loader = TDEGlobal::iconLoader();
 	const ViewContainerList::iterator vcEnd = m_viewContainerList.end();
 	for ( ViewContainerList::iterator it = m_viewContainerList.begin(); it != vcEnd; ++it )
 	{
@@ -1018,7 +1018,7 @@ void KTechlab::slotDocModifiedChanged()
 		TQString iconName;
 		
 		if ( vc->activeView()->document()->isModified() )
-			iconName = "filesave";
+			iconName = "document-save";
 		
 		else switch ( vc->activeView()->document()->type() )
 		{
@@ -1035,7 +1035,7 @@ void KTechlab::slotDocModifiedChanged()
 				break;
 				
 			case Document::dt_text:
-				iconName = "txt";
+				iconName = "text-plain";
 				break;
 				
 			case Document::dt_pinMapEditor:
@@ -1046,7 +1046,7 @@ void KTechlab::slotDocModifiedChanged()
 				break;
 		}
 		
-		tabWidget()->setTabIconSet( vc, loader->loadIcon( iconName, KIcon::Small ) );
+		tabWidget()->setTabIconSet( vc, loader->loadIcon( iconName, TDEIcon::Small ) );
 	}
 	//END Set tab icons
 }
@@ -1129,7 +1129,7 @@ void KTechlab::slotFilePrint()
 
 bool KTechlab::queryClose()
 {
-	saveProperties( KGlobal::config() );
+	saveProperties( TDEGlobal::config() );
 	
 	if ( DocManager::self()->closeAll() && ProjectManager::self()->slotCloseProject() )
 	{
@@ -1150,7 +1150,7 @@ void KTechlab::slotFileQuit()
 {
 	// close the first window, the list makes the next one the first again.
 	// This ensures that queryClose() is called on each window to ask for closing
-	KMainWindow* w;
+	TDEMainWindow* w;
 	if(memberList)
 	{
 		for( w=memberList->first(); w!=0; w=memberList->next() )
