@@ -29,9 +29,9 @@
 
 #include <kdebug.h>
 #include <klibloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <ktempfile.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdetempfile.h>
 
 
 TextDocument *TextDocument::constructTextDocument( const TQString& caption, KTechlab *parent, const char *name )
@@ -145,7 +145,7 @@ View * TextDocument::createView( ViewContainer *viewContainer, uint viewAreaId,
 
 Kate::View* TextDocument::createKateView( TQWidget *parent, const char *name )
 {
-	return static_cast<Kate::View*>((m_doc->createView( parent, name ))->qt_cast("Kate::View"));
+	return static_cast<Kate::View*>((m_doc->createView( parent, name ))->tqt_cast("Kate::View"));
 }
 
 
@@ -603,7 +603,7 @@ void TextDocument::slotUpdateMarksInfo()
 	{
 		if ( mark->type & Bookmark )
 		{
-			KAction * a = new KAction( i18n("%1 - %2").arg( TQString::number( mark->line+1 ) ).arg( m_doc->textLine(mark->line) ),
+			TDEAction * a = new TDEAction( i18n("%1 - %2").arg( TQString::number( mark->line+1 ) ).arg( m_doc->textLine(mark->line) ),
 									   0, this, TQT_SLOT(slotBookmarkRequested()), this,
 									   TQString("bookmark_%1").arg(TQString::number(mark->line).ascii()) );
 			m_bookmarkActions.append(a);
